@@ -2,11 +2,13 @@
 
 # flake8: noqa
 from __future__ import absolute_import
-
 # import models into model package
+from properly_model_python.search_models.models.lat_lng import LatLng
+from properly_model_python.search_models.models.lat_lng_bounds import LatLngBounds
 from properly_model_python.search_models.models.person import Person
 from properly_model_python.search_models.models.search import Search
 from properly_model_python.search_models.models.search_notification import SearchNotification
 from properly_model_python.search_models.models.search_result import SearchResult
 from properly_model_python.search_models.models.simple_listing import SimpleListing
 from properly_model_python.search_models.models.users_search import UsersSearch
+
